@@ -684,7 +684,7 @@ gnutls_x509_privkey_export (gnutls_x509_privkey_t key,
 			    gnutls_x509_crt_fmt_t format, void *output_data,
 			    size_t * output_data_size)
 {
-  char *msg;
+  const char *msg;
   int ret;
 
   if (key == NULL)
