@@ -304,6 +304,7 @@ generate_certificate (gnutls_x509_privkey_t * ret_key,
 	  get_cn_crt_set (crt);
 	  get_uid_crt_set (crt);
 	  get_oid_crt_set (crt);
+	  get_key_purpose_set( crt);
 
 	  if (!batch)
 	    fprintf (stderr,
@@ -929,6 +930,7 @@ gaa_parser (int argc, char **argv)
 
   gnutls_global_set_log_function (tls_log_func);
   gnutls_global_set_log_level (info.debug);
+  if (info.debug > 1) printf("Setting log level to %d\n", info.debug);
 
   if ((ret = gnutls_global_init ()) < 0)
     error (EXIT_FAILURE, 0, "global_init: %s", gnutls_strerror (ret));
@@ -2696,7 +2698,7 @@ pkcs12_info (void)
 
   result = gnutls_pkcs12_verify_mac (pkcs12, pass);
   if (result < 0)
-    error (EXIT_FAILURE, 0, "verify_mac: %s", gnutls_strerror (result));
+    error (0, 0, "verify_mac: %s", gnutls_strerror (result));
 
   indx = 0;
 
@@ -2728,8 +2730,10 @@ pkcs12_info (void)
 	  result = gnutls_pkcs12_bag_decrypt (bag, pass);
 
 	  if (result < 0)
-	    error (EXIT_FAILURE, 0, "bag_decrypt: %s",
-		   gnutls_strerror (result));
+	    {
+	      error (0, 0, "bag_decrypt: %s", gnutls_strerror (result));
+	      continue;
+	    }
 
 	  result = gnutls_pkcs12_bag_get_count (bag);
 	  if (result < 0)
