@@ -23,6 +23,8 @@
  * (which means it is quite unreadable)
  */
 
+#include <config.h>
+
 #include "common.h"
 #include "serv-gaa.h"
 #include <stdio.h>
@@ -740,6 +742,8 @@ unimplemented:
   *response_length = ((*response) ? strlen (*response) : 0);
 }
 
+static void terminate (int sig) __attribute__ ((noreturn));
+
 static void
 terminate (int sig)
 {
@@ -1431,6 +1435,8 @@ gaa_parser (int argc, char **argv)
   parse_comp (info.comp, info.ncomp, comp_priority);
 }
 
+extern void serv_version(void);
+
 void
 serv_version (void)
 {
