@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000,2001,2002,2003,2006,2007,2008,2009 Nikos Mavrogiannopoulos
+ * Copyright (C) 2000,2001,2002,2003,2006,2007,2008 Nikos Mavrogiannopoulos
  * Copyright (C) 2004,2005, 2008 Free Software Foundation
  *
  * This file is part of GNUTLS.
@@ -34,15 +34,13 @@
 
 #include <version-etc.h>
 
-#include "getaddrinfo.h"
-
 #define SA struct sockaddr
 #define ERR(err,s) if (err==-1) {perror(s);return(1);}
 #define MAX_BUF 4096
 
 /* global stuff here */
 int resume;
-char *hostname = NULL;
+const char *hostname = NULL;
 int port;
 int record_max_size;
 int fingerprint;
@@ -71,11 +69,11 @@ typedef test_code_t (*TEST_FUNC) (gnutls_session_t);
 
 typedef struct
 {
-  char *test_name;
+  const char *test_name;
   TEST_FUNC func;
-  char *suc_str;
-  char *fail_str;
-  char *unsure_str;
+  const char *suc_str;
+  const char *fail_str;
+  const char *unsure_str;
 } TLS_TEST;
 
 static const TLS_TEST tls_tests[] = {
@@ -328,6 +326,8 @@ gaa_parser (int argc, char **argv)
 
 }
 
+void tls_test_version (void);
+
 void
 tls_test_version (void)
 {
