@@ -22,7 +22,7 @@
 
 /* Parts copied from GnuTLS example programs. */
 
-#if HAVE_CONFIG_H
+#ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
 
@@ -37,6 +37,8 @@
 #include <unistd.h>
 #include <gnutls/gnutls.h>
 
+#include "tcp.c"
+
 #include "utils.h"
 
 /* A very basic TLS client, with PSK authentication.
@@ -51,53 +53,14 @@ tls_log_func (int level, const char *str)
   fprintf (stderr, "|<%d>| %s", level, str);
 }
 
-/* Connects to the peer and returns a socket
- * descriptor.
- */
-int
-tcp_connect (void)
-{
-  const char *PORT = "5556";
-  const char *SERVER = "127.0.0.1";
-  int err, sd;
-  struct sockaddr_in sa;
-
-  /* connects to server
-   */
-  sd = socket (AF_INET, SOCK_STREAM, 0);
-
-  memset (&sa, '\0', sizeof (sa));
-  sa.sin_family = AF_INET;
-  sa.sin_port = htons (atoi (PORT));
-  inet_pton (AF_INET, SERVER, &sa.sin_addr);
-
-  err = connect (sd, (struct sockaddr *) &sa, sizeof (sa));
-  if (err < 0)
-    {
-      fprintf (stderr, "Connect error\n");
-      exit (1);
-    }
-
-  return sd;
-}
-
-/* closes the given socket descriptor.
- */
-void
-tcp_close (int sd)
-{
-  shutdown (sd, SHUT_RDWR);	/* no more receptions */
-  close (sd);
-}
-
-void
+static void
 client (void)
 {
   int ret, sd, ii;
   gnutls_session_t session;
   char buffer[MAX_BUF + 1];
   gnutls_psk_client_credentials_t pskcred;
-  const gnutls_datum_t key = { "DEADBEEF", 8 };
+  const gnutls_datum_t key = { (char*) "DEADBEEF", 8 };
 
   gnutls_global_init ();
 
@@ -183,7 +146,7 @@ end:
 /* These are global */
 gnutls_psk_server_credentials_t server_pskcred;
 
-gnutls_session_t
+static gnutls_session_t
 initialize_tls_session (void)
 {
   gnutls_session_t session;
@@ -205,7 +168,7 @@ static gnutls_dh_params_t dh_params;
 static int
 generate_dh_params (void)
 {
-  const gnutls_datum_t p3 = { pkcs3, strlen (pkcs3) };
+  const gnutls_datum_t p3 = { (char*) pkcs3, strlen (pkcs3) };
   /* Generate Diffie Hellman parameters - for use with DHE
    * kx algorithms. These should be discarded and regenerated
    * once a day, once a week or once a month. Depending on the
@@ -238,7 +201,7 @@ gnutls_session_t session;
 char buffer[MAX_BUF + 1];
 int optval = 1;
 
-void
+static void
 server_start (void)
 {
   success ("Launched, generating DH parameters...\n");
@@ -279,7 +242,7 @@ server_start (void)
   success ("server: ready. Listening to port '%d'.\n", PORT);
 }
 
-void
+static void
 server (void)
 {
   /* this must be called once in the program
