@@ -37,6 +37,8 @@
 #include <unistd.h>
 #include <gnutls/gnutls.h>
 
+#include "tcp.c"
+
 #include "utils.h"
 
 static void wrap_db_init (void);
@@ -53,46 +55,7 @@ static int wrap_db_delete (void *dbf, gnutls_datum_t key);
 #define MAX_BUF 1024
 #define MSG "Hello TLS"
 
-/* Connects to the peer and returns a socket
- * descriptor.
- */
-int
-tcp_connect (void)
-{
-  const char *PORT = "5556";
-  const char *SERVER = "127.0.0.1";
-  int err, sd;
-  struct sockaddr_in sa;
-
-  /* connects to server
-   */
-  sd = socket (AF_INET, SOCK_STREAM, 0);
-
-  memset (&sa, '\0', sizeof (sa));
-  sa.sin_family = AF_INET;
-  sa.sin_port = htons (atoi (PORT));
-  inet_pton (AF_INET, SERVER, &sa.sin_addr);
-
-  err = connect (sd, (struct sockaddr *) &sa, sizeof (sa));
-  if (err < 0)
-    {
-      fprintf (stderr, "Connect error\n");
-      exit (1);
-    }
-
-  return sd;
-}
-
-/* closes the given socket descriptor.
- */
-void
-tcp_close (int sd)
-{
-  shutdown (sd, SHUT_RDWR);	/* no more receptions */
-  close (sd);
-}
-
-void
+static void
 client (void)
 {
   int ret, sd, ii;
@@ -223,7 +186,7 @@ client (void)
 /* These are global */
 gnutls_anon_server_credentials_t anoncred;
 
-gnutls_session_t
+static gnutls_session_t
 initialize_tls_session (void)
 {
   gnutls_session_t session;
@@ -257,7 +220,7 @@ static gnutls_dh_params_t dh_params;
 static int
 generate_dh_params (void)
 {
-  const gnutls_datum_t p3 = { pkcs3, strlen (pkcs3) };
+  const gnutls_datum_t p3 = { (char*) pkcs3, strlen (pkcs3) };
   /* Generate Diffie Hellman parameters - for use with DHE
    * kx algorithms. These should be discarded and regenerated
    * once a day, once a week or once a month. Depending on the
@@ -277,7 +240,7 @@ gnutls_session_t session;
 char buffer[MAX_BUF + 1];
 int optval = 1;
 
-void
+static void
 global_start (void)
 {
   /* Socket operations
@@ -316,7 +279,7 @@ global_start (void)
   success ("server: ready. Listening to port '%d'.\n", PORT);
 }
 
-void
+static void
 global_stop (void)
 {
   success ("global stop\n");
@@ -328,9 +291,11 @@ global_stop (void)
   gnutls_global_deinit ();
 }
 
-void
+static void
 server (void)
 {
+  size_t t;
+
   /* this must be called once in the program, it is mostly for the server.
    */
   gnutls_global_init ();
@@ -348,8 +313,6 @@ server (void)
       wrap_db_init ();
     }
 
-  int t;
-
   for (t = 0; t < 2; t++)
     {
       client_len = sizeof (sa_cli);
